@@ -1,42 +1,44 @@
 /*
  * Copyright (c) 2009 - 2011 Miek Gieben
- * See LICENSE for the license
+ * License: GPLv3(+), see LICENSE for details
  * make a dir writable and later remove that
  * right again
  */
 
 #include "rdup-up.h"
 
-struct stat *
-dir_write(gchar *p)
+struct stat *dir_write(gchar * p)
 {
-	 /* chmod +w . && rm $file && chmod -w # and hope for the best */
+	/* chmod +w . && rm $file && chmod -w # and hope for the best */
 	if (!p)
 		return NULL;
 
 	struct stat *s = g_malloc(sizeof(struct stat));
 #ifdef DEBUG
-	msgd(__func__, __LINE__,_("Making directory writable `%s\'"), p);
-#endif /* DEBUG */
+	msgd(__func__, __LINE__, _("Making directory writable `%s\'"), p);
+#endif				/* DEBUG */
 
 	if (stat(p, s) == -1)
 		return NULL;
 
 	/* make it writable, assume we are the OWNER */
 	if (chmod(p, s->st_mode | S_IWUSR) == -1) {
-		msgd(__func__, __LINE__,_("Failed to make directory writeable `%s\': %s"), p, strerror(errno));
+		msgd(__func__, __LINE__,
+		     _("Failed to make directory writeable `%s\': %s"), p,
+		     strerror(errno));
 	}
 	return s;
 }
 
-void
-dir_restore(gchar *p, struct stat *s)
+void dir_restore(gchar * p, struct stat *s)
 {
 	if (!s || !p)
 		return;
 	/* restore perms - assumes *s has not be f*cked up */
 	if (chmod(p, s->st_mode & 07777) == -1) {
-		msgd(__func__, __LINE__,_("Failed to restore permissions `%s\': %s"), p, strerror(errno));
+		msgd(__func__, __LINE__,
+		     _("Failed to restore permissions `%s\': %s"), p,
+		     strerror(errno));
 	}
 }
 
@@ -44,8 +46,7 @@ dir_restore(gchar *p, struct stat *s)
  * return parent dir string
  * p MUST not end in a /
  */
-gchar *
-dir_parent(gchar *p)
+gchar *dir_parent(gchar * p)
 {
 	gchar *p2;
 	gchar *n;
@@ -60,10 +61,10 @@ dir_parent(gchar *p)
 	copy = g_strdup(p);
 	n = strrchr(copy, '/');
 	if (n) {
-		*(n+1) = '\0';
+		*(n + 1) = '\0';
 		p2 = g_strdup(copy);
 		g_free(copy);
-		*n= '/';
+		*n = '/';
 		return p2;
 	}
 	return NULL;
