@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2005 - 2011 Miek Gieben
- * See LICENSE for the license
+ * License: GPLv3(+), see LICENSE for details
  * Reverse a GTree by putting all element in a GList
  * and reverse print that. Needed for rdup's -R switch
  */
@@ -11,8 +11,7 @@
 GList *list;
 
 /* Walk each element and put it in a list */
-GList *
-reverse(GTree *g)
+GList *reverse(GTree * g)
 {
 	list = NULL;
 	g_tree_foreach(g, gfunc_tree2list, NULL);
@@ -25,20 +24,17 @@ reverse(GTree *g)
  * skip all NO_PRINT entries, hence to harcoded
  * used of VALUE here.
  */
-void
-gfunc_new_list(gpointer data, gpointer userdata)
+void gfunc_new_list(gpointer data, gpointer userdata)
 {
 	(void)gfunc_new(data, VALUE, userdata);
 }
 
-void
-gfunc_remove_list(gpointer data, gpointer userdata)
+void gfunc_remove_list(gpointer data, gpointer userdata)
 {
 	(void)gfunc_remove(data, VALUE, userdata);
 }
 
-void
-gfunc_backup_list(gpointer data, gpointer userdata)
+void gfunc_backup_list(gpointer data, gpointer userdata)
 {
 	(void)gfunc_backup(data, VALUE, userdata);
 }
