@@ -1,3 +1,7 @@
+/*
+ * Copyright (c) 2009 - 2011 Miek Gieben
+ * License: GPLv3(+), see LICENSE for details
+ */
 #include "rdup-up.h"
 
 /* strip n components from pathname
@@ -23,7 +27,9 @@ static guint pathlabel(struct rdup *e)
 {
 	gint i, j = 0;
 
-	for(i = 0; i < (S_ISLNK(e->f_mode) || e->f_lnk == 1 ? e->f_size : (gint)e->f_name_size); i++) {
+	for (i = 0;
+	     i < (S_ISLNK(e->f_mode)
+		  || e->f_lnk == 1 ? e->f_size : (gint) e->f_name_size); i++) {
 		if (e->f_name[i] == '/')
 			j++;
 	}
@@ -31,16 +37,15 @@ static guint pathlabel(struct rdup *e)
 }
 
 /* this implements the -s option */
-void
-strippath(struct rdup *e)
+void strippath(struct rdup *e)
 {
 	char *p;
 	guint i;
 
-	if (! e->f_name)
+	if (!e->f_name)
 		return;
 
-	for(i = 1, p = strchr(e->f_name, '/'); p; p = strchr(p + 1, '/'), i++) {
+	for (i = 1, p = strchr(e->f_name, '/'); p; p = strchr(p + 1, '/'), i++) {
 		if (i > opt_strip)
 			break;
 	}
@@ -55,7 +60,8 @@ strippath(struct rdup *e)
 	e->f_name_size = strlen(p);
 
 	if (e->f_lnk == 1) {
-		for(i = 1, p = strchr(e->f_target, '/'); p; p = strchr(p + 1, '/'), i++) {
+		for (i = 1, p = strchr(e->f_target, '/'); p;
+		     p = strchr(p + 1, '/'), i++) {
 			if (i > opt_strip)
 				break;
 		}
@@ -66,13 +72,12 @@ strippath(struct rdup *e)
 }
 
 /* this implements the -r options, strip opt_strip_path from each name */
-void
-strippathname(struct rdup *e)
+void strippathname(struct rdup *e)
 {
 	gchar *where;
 	guint len;
 
-	if (! e->f_name)
+	if (!e->f_name)
 		return;
 
 	/* the other way around, if the path is a prefix of the prefix
@@ -81,21 +86,21 @@ strippathname(struct rdup *e)
 	 */
 	(void)pathlabel(e);
 #ifdef DEBUG
-	msgd(__func__, __LINE__,_("Label %d, strippathlen %d\n"), pathlabel(e),
-			opt_path_strip_len);
-#endif /* DEBUG */
+	msgd(__func__, __LINE__, _("Label %d, strippathlen %d\n"), pathlabel(e),
+	     opt_path_strip_len);
+#endif				/* DEBUG */
 /*	if (pathlabel(e) > opt_path_strip_len) { */
-		if (g_str_has_prefix(opt_path_strip, e->f_name)) {
-			e->f_name = NULL;
-			e->f_name_size = 0;
-			return;
-		}
+	if (g_str_has_prefix(opt_path_strip, e->f_name)) {
+		e->f_name = NULL;
+		e->f_name_size = 0;
+		return;
+	}
 /*	} */
 
 	if (g_str_has_prefix(e->f_name, opt_path_strip) == FALSE)
 		return;
 
-	len = strlen(opt_path_strip) - 1; /* -1: discard the trailing slash */
+	len = strlen(opt_path_strip) - 1;	/* -1: discard the trailing slash */
 	where = e->f_name + len;
 
 	/* string starts with opt_path_strip, so we can just jump
@@ -105,7 +110,7 @@ strippathname(struct rdup *e)
 	memmove(e->f_name, where, e->f_name_size - len);
 	e->f_name_size -= len;
 	e->f_name[e->f_name_size] = '\0';
-	
+
 	if (S_ISLNK(e->f_mode) || e->f_lnk == 1)
 		e->f_size -= len;
 
