@@ -1,17 +1,16 @@
 /*
  * Copyright (c) 2009 - 2011 Miek Gieben
- * See LICENSE for the license
+ * License: GPLv3(+), see LICENSE for details
  */
 
 #include "rdup-tr.h"
 
 extern char *PROGNAME;
 
-void
-usage_tr(FILE *f)
+void usage_tr(FILE * f)
 {
-        fprintf(f, _("USAGE: %s [OPTION]... \n"), PROGNAME);
-	fputs( _("\
+	fprintf(f, _("USAGE: %s [OPTION]... \n"), PROGNAME);
+	fputs(_("\
 Translate rdup output into something else.\n\
 \n\
 \n\
