@@ -1,17 +1,16 @@
 /*
  * Copyright (c) 2009 - 2011 Miek Gieben
- * See LICENSE for the license
+ * License: GPLv3(+), see LICENSE for details
  */
 
 #include "rdup-up.h"
 
 extern char *PROGNAME;
 
-void
-usage_up(FILE *f)
+void usage_up(FILE * f)
 {
-        fprintf(f, _("USAGE: %s [OPTION]... DIRECTORY\n"), PROGNAME);
-	fputs( _("\
+	fprintf(f, _("USAGE: %s [OPTION]... DIRECTORY\n"), PROGNAME);
+	fputs(_("\
 Update a directory tree with an rdup archive.\n\
 \n\
         DIRECTORY\twhere to unpack the archive\n\
@@ -24,6 +23,8 @@ Update a directory tree with an rdup archive.\n\
 	-n\t\tdry run, do not touch the filesystem\n\
 	-V\t\tprint version\n\
 	-T\t\tshow table of contents. DIRECTORY is optional\n\
+        -u\t\tdo not create ._rdup_. with user/group information\n\
+        -q\t\tsilence \'chown\' failures even when \'root\'\n\
 	-h\t\tthis help\n\
 	-v\t\tbe more verbose and print processed files to stdout\n\
 \n\
